aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/core
diff options
context:
space:
mode:
authorGravatar commit-bot@chromium.org <commit-bot@chromium.org@2bbb7eff-a529-9590-31e7-b0007b416f81>2014-04-21 21:09:38 +0000
committerGravatar commit-bot@chromium.org <commit-bot@chromium.org@2bbb7eff-a529-9590-31e7-b0007b416f81>2014-04-21 21:09:38 +0000
commit6b4aaa77dcc4f17d0e22986f5f4cca70011d1ee5 (patch)
tree35db9e96118aa74cf77f1cbbca998a79f3033e42 /include/core
parent2c4e75cc3c0302e0e151d90c74b4c476bfa8a8b5 (diff)
add optional origin parameter to accessTopLayerPixels
BUG=skia: R=bsalomon@google.com Author: reed@google.com Review URL: https://codereview.chromium.org/244763004 git-svn-id: http://skia.googlecode.com/svn/trunk@14290 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'include/core')
-rw-r--r--include/core/SkCanvas.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/include/core/SkCanvas.h b/include/core/SkCanvas.h
index 6a15c047bc..0a81969468 100644
--- a/include/core/SkCanvas.h
+++ b/include/core/SkCanvas.h
@@ -206,15 +206,14 @@ public:
* If the canvas has writable pixels in its top layer (and is not recording to a picture
* or other non-raster target) and has direct access to its pixels (i.e. they are in
* local RAM) return the address of those pixels, and if not null,
* return the ImageInfo and rowBytes. The returned address is only valid
* while the canvas object is in scope and unchanged. Any API calls made on
* canvas (or its parent surface if any) will invalidate the
* returned address (and associated information).
*
* On failure, returns NULL and the info and rowBytes parameters are
* ignored.
*/
- void* accessTopLayerPixels(SkImageInfo* info, size_t* rowBytes);
+ void* accessTopLayerPixels(SkImageInfo* info, size_t* rowBytes, SkIPoint* origin = NULL);
/**
* If the canvas has readable pixels in its base layer (and is not recording to a picture
@@ -206,15 +206,14 @@ public:
* or other non-raster target) and has direct access to its pixels (i.e. they are in
* local RAM) return the address of those pixels, and if not null,
- * return the ImageInfo and rowBytes. The returned address is only valid
+ * return the ImageInfo, rowBytes and origin. The returned address is only valid
* while the canvas object is in scope and unchanged. Any API calls made on
* canvas (or its parent surface if any) will invalidate the
@@ -206,15 +206,14 @@ public:
* returned address (and associated information).
*
- * On failure, returns NULL and the info and rowBytes parameters are
- * ignored.
+ * On failure, returns NULL and the info, rowBytes, and origin parameters are ignored.
*/